==> Mapster-1.4.3.zip: Mapster/Locale/esMX.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "esMX")
if not L then return end

-- L["(Mini) Disable Mouse"] = "(Mini) Disable Mouse"
-- L["(Mini) Hide Border"] = "(Mini) Hide Border"
-- L["Accuracy"] = "Accuracy"
-- L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Adjust the size of the Player Arrow on the Map for better visibility."
-- L["Alpha"] = "Alpha"
-- L["BattleMap"] = "BattleMap"
-- L["Battlegrounds"] = "Battlegrounds"
-- L["Blobs & Panels"] = "Blobs & Panels"
-- L["Burning Crusade Instances"] = "Burning Crusade Instances"
-- L["Burning Crusade Raids"] = "Burning Crusade Raids"
-- L["Cataclysm Instances"] = "Cataclysm Instances"
-- L["Cataclysm Raids"] = "Cataclysm Raids"
-- L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Change the scale of the world map if you do not want the whole screen filled while the map is open."
-- L["Classic Instances"] = "Classic Instances"
-- L["Classic Raids"] = "Classic Raids"
-- L["Coordinates"] = "Coordinates"
-- L["Cursor"] = "Cursor"
-- L["Debug"] = "Debug"
-- L["Disable Mouse"] = "Disable Mouse"
-- L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."
-- L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disable the mouse interactivity of the main map, eg. to change zones."
-- L["Enable BattleMap"] = "Enable BattleMap"
-- L["Enable Coordinates"] = "Enable Coordinates"
-- L["Enable FogClear"] = "Enable FogClear"
-- L["Enable Group Icons"] = "Enable Group Icons"
-- L["Enable Instance Maps"] = "Enable Instance Maps"
-- L["FogClear"] = "FogClear"
-- L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."
-- L["Group Icons"] = "Group Icons"
-- L["Hide Border"] = "Hide Border"
-- L["Hide Completely"] = "Hide Completely"
-- L["Hide Map Button"] = "Hide Map Button"
-- L["Hide Textures"] = "Hide Textures"
-- L["Hide the borders of the big map."] = "Hide the borders of the big map."
-- L["Hide the borders of the minimized map."] = "Hide the borders of the minimized map."
-- L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."
-- L["Instance Maps"] = "Instance Maps"
-- L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."
-- L["Minimized Alpha"] = "Minimized Alpha"
-- L["Minimized Scale"] = "Minimized Scale"
-- L["Note: You need to reload your UI after reseting the data!"] = "Note: You need to reload your UI after reseting the data!"
-- L["Only WorldMap Blobs"] = "Only WorldMap Blobs"
-- L["Overlay Color"] = "Overlay Color"
-- L["POI Scale"] = "POI Scale"
-- L["Player"] = "Player"
-- L["PlayerArrow Scale"] = "PlayerArrow Scale"
-- L["Quest Objectives"] = "Quest Objectives"
-- L["Reset FogClear Data"] = "Reset FogClear Data"
-- L["Scale"] = "Scale"
-- L["Scale of the POI Icons on the Map."] = "Scale of the POI Icons on the Map."
-- L["Scale of the big map."] = "Scale of the big map."
-- L["Scale of the minimized map."] = "Scale of the minimized map."
-- L["Size on the Battle Map"] = "Size on the Battle Map"
-- L["Size on the World Map"] = "Size on the World Map"
-- L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."
-- L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."
-- L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."
-- L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "The Group Icons module allows you to resize the raid and party icons on the world map."
-- L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."
-- L["The transparency of the big map."] = "The transparency of the big map."
-- L["The transparency of the minimized map."] = "The transparency of the minimized map."
-- L["Turn on debugging for the FogClear Module."] = "Turn on debugging for the FogClear Module."
-- L["Wrath Instances"] = "Wrath Instances"
-- L["Wrath Raids"] = "Wrath Raids"
-- L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."
-- L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."

==> Mapster-1.5.6.1.zip: Mapster/Locale/esMX.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "esMX")
if not L then return end

-- L["Accuracy"] = "Accuracy"
-- L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Adjust the size of the Player Arrow on the Map for better visibility."
-- L["Alpha"] = "Alpha"
-- L["Battlegrounds"] = "Battlegrounds"
-- L["BattleMap"] = "BattleMap"
-- L["Blobs & Panels"] = "Blobs & Panels"
-- L["Burning Crusade Instances"] = "Burning Crusade Instances"
-- L["Burning Crusade Raids"] = "Burning Crusade Raids"
-- L["Cataclysm Instances"] = "Cataclysm Instances"
-- L["Cataclysm Raids"] = "Cataclysm Raids"
-- L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Change the scale of the world map if you do not want the whole screen filled while the map is open."
-- L["Classic Instances"] = "Classic Instances"
-- L["Classic Raids"] = "Classic Raids"
-- L["Coordinates"] = "Coordinates"
-- L["Cursor"] = "Cursor"
-- L["Debug"] = "Debug"
-- L["Disable Mouse"] = "Disable Mouse"
-- L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disable the mouse interactivity of the main map, eg. to change zones."
-- L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."
-- L["EJ Icon Scale"] = "EJ Icon Scale"
-- L["Enable BattleMap"] = "Enable BattleMap"
-- L["Enable Coordinates"] = "Enable Coordinates"
-- L["Enable FogClear"] = "Enable FogClear"
-- L["Enable Group Icons"] = "Enable Group Icons"
-- L["Enable Instance Maps"] = "Enable Instance Maps"
-- L["FogClear"] = "FogClear"
-- L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."
-- L["Group Icons"] = "Group Icons"
-- L["Hide Border"] = "Hide Border"
-- L["Hide Completely"] = "Hide Completely"
-- L["Hide Map Button"] = "Hide Map Button"
-- L["Hide Quest Panels"] = "Hide Quest Panels"
-- L["Hide Textures"] = "Hide Textures"
-- L["Hide the borders of the big map."] = "Hide the borders of the big map."
-- L["Hide the borders of the minimized map."] = "Hide the borders of the minimized map."
-- L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."
-- L["Instance Maps"] = "Instance Maps"
-- L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."
-- L["(Mini) Disable Mouse"] = "(Mini) Disable Mouse"
-- L["(Mini) Hide Border"] = "(Mini) Hide Border"
-- L["Minimized Alpha"] = "Minimized Alpha"
-- L["Minimized Scale"] = "Minimized Scale"
-- L["Note: You need to reload your UI after reseting the data!"] = "Note: You need to reload your UI after reseting the data!"
-- L["Only WorldMap Blobs"] = "Only WorldMap Blobs"
-- L["Overlay Color"] = "Overlay Color"
-- L["Pandaria Instances"] = "Pandaria Instances"
-- L["Pandaria Raids"] = "Pandaria Raids"
-- L["Player"] = "Player"
-- L["PlayerArrow Scale"] = "PlayerArrow Scale"
-- L["POI Scale"] = "POI Scale"
-- L["Reset FogClear Data"] = "Reset FogClear Data"
-- L["Scale"] = "Scale"
-- L["Scale of the big map."] = "Scale of the big map."
-- L["Scale of the Encounter Journal Icons on the Map."] = "Scale of the Encounter Journal Icons on the Map."
-- L["Scale of the minimized map."] = "Scale of the minimized map."
-- L["Scale of the POI Icons on the Map."] = "Scale of the POI Icons on the Map."
-- L["Size on the Battle Map"] = "Size on the Battle Map"
-- L["Size on the World Map"] = "Size on the World Map"
-- L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."
-- L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."
-- L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."
-- L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "The Group Icons module allows you to resize the raid and party icons on the world map."
-- L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."
-- L["The transparency of the big map."] = "The transparency of the big map."
-- L["The transparency of the minimized map."] = "The transparency of the minimized map."
-- L["Turn on debugging for the FogClear Module."] = "Turn on debugging for the FogClear Module."
-- L["Wrath Instances"] = "Wrath Instances"
-- L["Wrath Raids"] = "Wrath Raids"
-- L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."
-- L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."
